from typing import List

from astra_installer.commands import run_command, readfile


class HardwareReporter:
    def __init__(self) -> None:
        self.commands = ['uname -a',
                         'lspci -knn',
                         'usb-devices',
                         'lsusb',
                         'lsmod',
                         'lsblk',
                         'df',
                         'free',
                         'pccardctl status',
                         'pccardctl ident',
                         'dmraid -s',
                         'dmraid -r',
                         'dmsetup table',
                         'dmidecode']
        self.files = ['/proc/cmdline',
                      '/proc/cpuinfo',
                      '/proc/ioports',
                      '/proc/iomem',
                      '/proc/interrupts',
                      '/proc/meminfo',
                      '/proc/bus/input/devices',
                      '/proc/fb']
        self.commands_output = []  # type: List[str]
        self.files_content = []  # type: List[str]

    def hardware_summary(self) -> str:
        for command in self.commands:
            self.log_command(command)
        for file in self.files:
            self.log_file(file)
        commands_output = '\n'.join(self.commands_output)
        files_content = ''.join(self.files_content)
        return '{}\n{}'.format(commands_output, files_content)

    @staticmethod
    def entity_lines(entity: str, lines: List[str]) -> List[str]:
        return ['{}: {}'.format(entity, line) for line in lines]

    def log_command(self, command: str) -> None:
        lines = run_command(command, expect_success=False, enable_logging=False).stdout
        self.commands_output.extend(HardwareReporter.entity_lines(command, lines))

    def log_file(self, file: str) -> None:
        try:
            lines = readfile(file)
            self.files_content.extend(HardwareReporter.entity_lines(file, lines))
        except FileNotFoundError:
            pass
