import re
from typing import Optional

from astra_installer.commands import run_command, Chroot
from astra_installer.logs.logger import Logger


class PackageInfo:
    def __init__(self,
                 name: str,
                 version: str) -> None:
        self.__name = name
        self.__version = version

    def __repr__(self) -> str:
        return self.__name

    @property
    def name(self) -> str:
        return self.__name

    @property
    def version(self) -> str:
        return self.__version


class Package:
    INSTALLED_REGEX = re.compile(r'ii')

    def __init__(self, name: str) -> None:
        self.__name = name

    def __repr__(self) -> str:
        return self.__name

    @property
    def name(self) -> str:
        return self.__name

    def get_info(self, in_chroot: Optional[Chroot] = None) -> Optional[PackageInfo]:
        command = 'dpkg-query -W -f="\\${{binary:Package}}|\\${{Version}}|' \
                  '\\${{db:Status-Abbrev}}" {name}'.format(name=self.__name)

        if in_chroot:
            result = in_chroot.run_command(command=command, expect_success=False)
        else:
            result = run_command(command=command, expect_success=False)

        info = None
        if not result.is_fail:
            try:
                name, version, status = result.stdout[0].split('|')
                if bool(re.search(self.INSTALLED_REGEX, status)):
                    info = PackageInfo(name=name, version=version)
            except Exception as e:
                Logger.log(str(e))
        return info
