#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import Dict, Any, TYPE_CHECKING

import yaml

from astra_installer.settings.config import ConfigLoader
from astra_installer.translator import deferredtr as _tr

if TYPE_CHECKING:
    from gettext import gettext as _

class AutoinstallConfigLoader(ConfigLoader):
    def __init__(self, preseed: str) -> None:
        super().__init__()
        self.preseed = preseed

    def load(self) -> Dict[str, Any]:
        config = super().load()
        preseed_config = ConfigLoader.load_file(self.preseed)
        config.update({'preseed': preseed_config})
        return config


class IndentDumper(yaml.Dumper):
    def increase_indent(self, flow=False, indentless=False):
        return super(IndentDumper, self).increase_indent(flow, False)


class AutoinstallConfigSaver():
    comment = _tr("# The use of this autoresponse file for the correct execution of the automatic installation\n"
                  "# means that the end user accepts the terms of the EULA posted at https://astralinux.ru/information/licenses\n\n")

    mode_prefix_comment = _tr("\n# Setting this parameter determines the OS security level\n"
                            "# corresponding to the license purchased from the Licensor:\n\n")
    mode_postfix_comment = _tr("\n# where mode is the security level (required parameter):\n"
                             "# 0 - Orel, 1 - Voronezh, 2 - Smolensk.\n"
                             "# In the absence of this parameter, automatic installation is not possible!\n\n")

    @staticmethod
    def save(config: Dict[str, Any]) -> None:
        with open('/var/log/astra-installer-preseed.yaml', 'w') as file:
            # PyYAML isn't supporting comments yet
            # We need to hack it
            file.write(_(AutoinstallConfigSaver.comment))
            mode = config.pop('mode', '')
            file.write(_(AutoinstallConfigSaver.mode_prefix_comment))
            yaml.dump({'mode': mode}, file, Dumper=IndentDumper, default_flow_style=False)
            file.write(_(AutoinstallConfigSaver.mode_postfix_comment))
            yaml.dump(config, file, Dumper=IndentDumper, default_flow_style=False)
