from typing import List, NewType

ComponentId = NewType('ComponentId', str)


class Component:
    def __init__(self, ident: ComponentId, name: str, desc: str,
                 full_desc: str, enabled: bool, selected: bool,
                 visible: bool, priority: float, dependencies: List[ComponentId]) -> None:
        self.ident = ident
        self.name = name
        self.desc = desc
        self.enabled = enabled
        self.selected = selected
        self.visible = visible
        self.priority = priority
        self.dependencies = dependencies
        self.__full_desc = full_desc

    @property
    def full_desc(self) -> str:
        return self.__full_desc

    def __str__(self) -> str:
        return self.ident


def has_component_with_ident(ident: str, components: List[Component]) -> bool:
    return any(component.ident == ident for component in components)
