from abc import ABC, abstractmethod
from typing import TypeVar, Type, cast, List, Dict, Any

from astra_installer.settings.component import Component


class ComponentsSetting(ABC):
    @property
    @abstractmethod
    def components(self) -> List[Component]:
        pass

    @components.setter
    @abstractmethod
    def components(self, components: List[Component]) -> None:
        pass

    @property
    @abstractmethod
    def exclusive_components(self) -> bool:
        pass

    @abstractmethod
    def load_components(self) -> None:
        pass

    @property
    @abstractmethod
    def is_components_loaded(self) -> bool:
        pass

    @property
    @abstractmethod
    def error(self) -> str:
        pass

    @property
    @abstractmethod
    def is_valid(self) -> bool:
        pass

    @abstractmethod
    def log_selected(self) -> None:
        pass

    @abstractmethod
    def dump_selected(self) -> Dict[str, Any]:
        pass

    a = TypeVar('a', bound='ComponentsSetting')

    def trycast(self, clazz: Type[a]) -> a:
        if not isinstance(self, clazz):
            raise RuntimeError('Expected {} instance, got {} instance'.format(clazz, self.__class__))
        return cast(clazz, self)
