from typing import List, Dict, Any

from astra_installer.settings.repository import Repository


class DiskSetting:
    def __init__(self,
                 target_path: str,
                 sources: List[Repository],
                 debootstrap: Repository,
                 use_eatmydata: bool,
                 late_command: str = '',
                 late_command_intarget: str = '') -> None:
        self.__target_path = target_path
        self.__sources = sources
        self.__debootstrap = debootstrap
        self.__use_eatmydata = use_eatmydata
        self.__late_command = late_command
        self.__late_command_intarget = late_command_intarget
        self.__reboot_after_install = False

    @property
    def target_path(self) -> str:
        return self.__target_path

    @target_path.setter
    def target_path(self, path: str) -> None:
        self.__target_path = path

    @property
    def sources(self) -> List[Repository]:
        return self.__sources

    @property
    def debootstrap(self) -> Repository:
        return self.__debootstrap

    @property
    def use_eatmydata(self) -> bool:
        return self.__use_eatmydata

    @use_eatmydata.setter
    def use_eatmydata(self, value: bool) -> None:
        self.__use_eatmydata = value

    @property
    def late_command(self) -> str:
        return self.__late_command

    @late_command.setter
    def late_command(self, path: str) -> None:
        self.__late_command = path

    @property
    def late_command_intarget(self) -> str:
        return self.__late_command_intarget

    @late_command_intarget.setter
    def late_command_intarget(self, path: str) -> None:
        self.__late_command_intarget = path

    @property
    def reboot_after_install(self) -> bool:
        return self.__reboot_after_install

    @reboot_after_install.setter
    def reboot_after_install(self, value: bool) -> None:
        self.__reboot_after_install = value

    def dump_selected(self) -> Dict[str, Any]:
        return {'repos': {'sources': [source.url for source in self.__sources], 'debootstrap': self.__debootstrap.url}}
