import re
from typing import Dict, Any, Tuple, Optional

from astra_installer.logs.logger import Logger
from astra_installer.translator import deferredtr as _tr


class HostnameSetting:
    def __init__(self, hostname: str) -> None:
        super().__init__()
        self.hostname = hostname

    def is_valid(self) -> bool:
        return self.is_valid_hostname(self.hostname)[0]

    @staticmethod
    def is_valid_hostname(hostname: str) -> Tuple[bool, Optional[str]]:
        if len(hostname) <= 63 and bool(re.match(r'^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])*$', hostname)):
            return True, None
        return False, _tr('Hostname may contain only the numbers 0-9, upper and lowercase letters, '
                          ' and the minus sign. It must be at least 1 character long and at most 63 '
                          'characters long, and may not begin or end with a minus sign')

    def log_selected(self) -> None:
        Logger.log('Selected hostname is "{hostname}"'.format(hostname=self.hostname))

    def dump_selected(self) -> Dict[str, Any]:
        return {'hostname': self.hostname}
