from typing import List, Dict, Any

from astra_installer.logs.logger import Logger
from astra_installer.translator import Translator


class InstallerLocaleSetting:
    def __init__(self, locales: List[str], default: str) -> None:
        super().__init__()
        self.locales = locales
        self.default = default
        self.selected = self.default
        self.change_locale(self.selected)

    def change_locale(self, locale: str) -> None:
        self.selected = locale
        Translator.change_locale(locale)

    def selected_country(self) -> str:
        return self.selected[3:].lower()

    def selected_language(self) -> str:
        return self.selected[:2].lower()

    def log_selected(self) -> None:
        Logger.log('Selected installer locale is "{locale}"'.format(locale=self.selected))

    def dump_selected(self) -> Dict[str, Any]:
        return {'installer_locale': self.selected}
