from typing import List, Dict, Any

from astra_installer.settings.security_feature import SecurityFeature
from astra_installer.logs.logger import Logger


class Mode:
    def __init__(self, ident: str, name: str, desc: str,
                 selected: bool, features: List[SecurityFeature]) -> None:
        self.ident = ident
        self.name = name
        self.desc = desc
        self.selected = selected
        self.features = features


class ModeSetting:
    def __init__(self, modes: List[Mode]) -> None:
        self.modes = modes

    def selected_mode(self) -> Mode:
        return next(mode for mode in self.modes if mode.selected)

    def log_selected(self) -> None:
        mode = next((mode.name for mode in self.modes if mode.selected), 'Smolensk')
        Logger.log('Selected mode is "{mode}"'.format(mode=mode))

    def dump_selected(self) -> Dict[str, Any]:
        mode = next((mode.ident for mode in self.modes if mode.selected), 2)
        return {'mode': mode}
