import os
import re


class Repository:
    regex = re.compile(r'^(?P<scheme>.*?)://(?P<path>.*?)$')

    def __init__(self, url: str) -> None:
        self.url = url

    @property
    def scheme(self) -> str:
        match = self.regex.match(self.url)
        return match.group('scheme')

    @property
    def path(self) -> str:
        match = self.regex.match(self.url)
        return match.group('path')

    @property
    def is_valid(self) -> bool:
        return bool(self.regex.match(self.url))

    @property
    def is_local(self) -> bool:
        return self.is_valid and self.scheme == 'file'

    @property
    def is_local_and_exists(self) -> bool:
        return self.is_local and os.path.isdir(self.path)

    def __str__(self) -> str:
        return self.url
