from enum import Enum
from typing import Set

from astra_installer.logs.logger import Logger


class AstraEdition(Enum):
    CE = 1
    SE = 2


class SystemInfo:
    def __init__(self, efi: bool, bios_compat_mode_supported: bool,
                 ram: int, arch: str, name: str, edition: AstraEdition,
                 release: str, scripts_path: str, oem: bool, is_kiosk_session: bool,
                 has_valid_repository: bool, installedpkgs: Set[str], test: bool) -> None:
        self.efi = efi
        self.bios_compat_mode_supported = bios_compat_mode_supported
        self.ram = ram
        self.arch = arch
        self.name = name
        self.edition = edition
        self.release = release
        self.scripts_path = scripts_path
        self.oem = oem
        self.is_kiosk_session = is_kiosk_session
        self.has_valid_repository = has_valid_repository
        self.installedpkgs = installedpkgs
        self.test = test

    @staticmethod
    def astra_edition(edition: str) -> AstraEdition:
        if edition == 'CE':
            return AstraEdition.CE
        else:
            return AstraEdition.SE

    def log_selected(self) -> None:
        Logger.log('Selected arch is "{arch}"'.format(arch=self.arch))
        Logger.log('Selected codename is "{codename}"'.format(codename=self.name))
        Logger.log('Selected release is "{release}"'.format(release=self.release))
