import subprocess
from typing import List, Set

from astra_installer.settings.component import Component, ComponentId


class Task(Component):
    name_by_id = {
        'Base': 'Console utilities',
        'DesktopSystemTools': 'Desktop system tools',
        'ServerSystemTools': 'Server system tools',
        'Fly': 'Fly GUI',
        'Internet': 'Internet tools',
        'Office': 'Office applications',
        'Graphics': 'Graphics tools',
        'Multimedia': 'Multimedia',
        'Games': 'Games',
        'Fly-qml': 'Touchscreen support',
        'Development': 'Development tools',
        'Fly-virtualization': 'Virtualization tools',
        'Fly-ssh': 'SSH server',
        'Database': 'Databases',
        'Fly-web': 'Secure WEB server',
        'hidden': 'Hidden task',
        'FlyDrivers': 'Tuning video drivers',
        'Ufw': 'Network packets filtering tools ufw',
        'Hardened': 'Hardened kernel'
    }

    def __init__(self, ident: ComponentId, name: str, desc: str,
                 enabled: bool, selected: bool, visible: bool,
                 priority: float, hook_path: str,
                 dependencies: List[ComponentId],
                 enhances: Set[ComponentId]) -> None:
        super().__init__(ident, name, desc, desc, enabled, selected,
                         visible, priority, dependencies)
        self.hook_path = hook_path
        self.enhances = enhances

    @property
    def tasksel_name(self) -> str:
        return self.ident

    def is_installed(self, installedpkgs: Set[str]) -> bool:
        # Python impl does not give performance improvement for some reason
        # blacklist = {'baytrail-install', 'fly-all-main'}
        # result = subprocess.run('tasksel --task-packages {task}'.format(task=self.ident),
        #                         shell=True, stdout=subprocess.PIPE, stderr=subprocess.DEVNULL)
        # if result.returncode == 0:
        #     for line in result.stdout.split():
        #         if line.decode() not in installedpkgs:
        #             return False
        #     # return set(result.stdout.split()).issubset(installedpkgs)
        #     return True
        # else:
        #     return False
        # return is_task_installed(self.ident)
        result = subprocess.run('tasksel --task-packages {task}'.format(task=self.ident),
                                shell=True, stdout=subprocess.PIPE, stderr=subprocess.DEVNULL)
        if result.returncode == 0:
            task_packages = set([bytestring.decode() for bytestring in result.stdout.split()])
            if len(task_packages) == 0:
                return False
            installed_task_packages = task_packages.intersection(installedpkgs)
            percentage = float(len(installed_task_packages)) / float(len(task_packages)) * 100 if task_packages else 100
            return percentage > 70
        else:
            return False

    @staticmethod
    def get_name_by_id(ident: str) -> str:
        return Task.name_by_id.get(ident, ident)
