from typing import List, Dict, Any, Optional

import pytz

from astra_installer.commands import run_command
from astra_installer.logs.logger import Logger


class TimezoneSetting:
    def __init__(self, timezone_settings: Dict[str, Any], selected: str) -> None:
        super().__init__()
        self.all_timezones = pytz.common_timezones
        self.timezone_settings = timezone_settings
        self.selected = selected

    def available_timezones(self, locale=None) -> List:
        timezones_by_locale_settings = self.timezone_settings.get('timezones_by_locale', {})
        timezones_by_locale = timezones_by_locale_settings.get(locale, {}).get('timezones')
        if timezones_by_locale:
            return [pytz.timezone(timezone) for timezone in timezones_by_locale]
        else:
            return [pytz.timezone(timezone) for timezone in self.all_timezones]

    def default_timezone(self, locale=None) -> Optional[object]:
        timezones_by_locale_settings = self.timezone_settings.get('timezones_by_locale', {})
        default_locale_timezone = timezones_by_locale_settings.get(locale, {}).get('default')
        if default_locale_timezone:
            return pytz.timezone(default_locale_timezone)
        elif self.selected:
            return pytz.timezone(self.selected)
        else:
            return None

    def is_valid(self) -> bool:
        return self.selected is not None

    def apply(self) -> None:
        if self.is_valid():
            Logger.log('Setting timezone to {timezone}'.format(timezone=self.selected))
            run_command('timedatectl set-timezone {timezone}'.format(timezone=self.selected))

    def log_selected(self) -> None:
        Logger.log('Selected timezone is "{timezone}"'.format(timezone=self.selected))

    def dump_selected(self) -> Dict[str, Any]:
        return {'timezone': self.selected}
