import crypt
import random
from re import match
from typing import Tuple, Optional, TYPE_CHECKING, Dict, Any

from astra_installer.logs.logger import Logger

if TYPE_CHECKING:
    from gettext import gettext as _


class UserSetting:
    username_blacklist = {'root'}

    def __init__(self, username: str,
                 password: str = '',
                 encrypted: bool = False,
                 setup_grub_password: bool = False,
                 grub_password: str = '',
                 grub_passowrd_encrypted: bool = False) -> None:
        super().__init__()
        self.username = username
        self.password = password
        self.encrypted = encrypted
        self.setup_grub_password = setup_grub_password
        self.grub_password = grub_password
        self.grub_password_encrypted = grub_passowrd_encrypted

    def is_valid(self) -> bool:
        return self.is_valid_username(self.username)[0] and self.password is not None

    @staticmethod
    def is_valid_username(username: str) -> Tuple[bool, Optional[str]]:
        if len(username) == 0 or not match(r'^[a-z]([-a-z0-9]{0,31})$', username):
            return False, _('Username must start with a lower-case letter, which can be followed '
                            'by any combination of numbers and more lower-case letters, '
                            'and must be not less than 1 character and no more than 32 characters long')
        if username in UserSetting.username_blacklist:
            return False, _('Username you entered is reserved for use by the system or already exists')
        return True, None

    @staticmethod
    def is_valid_password(password: str) -> Tuple[bool, Optional[str]]:
        if len(password) < 8:
            return False, _('Password should be at least 8 characters long.\nA good password will contain a '
                            'mixture of letters, numbers and punctuation and should be changed at regular intervals')
        return True, None

    @staticmethod
    def encrypt_password(password: str) -> str:
        random.seed()
        return crypt.crypt(password, crypt.METHOD_SHA512)

    def log_selected(self) -> None:
        Logger.log('Selected username is "{username}"'.format(username=self.username))

    def dump_selected(self) -> Dict[str, Any]:
        return {'user': {'username': self.username, 'password-encrypted': '', 'grub-password-encrypted': ''}}
