from astra_installer.commands import extract_archive
from astra_installer.logs.logger import Logger
from astra_installer.settings.archives import ArchivesSetting
from astra_installer.settings.manager import SettingsManager
from astra_installer.setup.common.disk import DiskInstall


class DiskInstallArchive(DiskInstall):
    def __init__(self) -> None:
        super().__init__()

    def make_chroot(self) -> None:
        Logger.log('Prepairing chrooted environment')
        self.mount_filesystems()
        self.copy_overrides('preinst_overrides')
        self.write_sources()
        self.add_cdrom()

    def setup_bootloader(self) -> None:
        device = SettingsManager.storage.current_template.storage_state.bootable_device()
        Logger.log('Installing grub to {device}'.format(device=device.path))
        self.chroot.run_command('grub-install {path}'.format(path=device.path))
        self.chroot.run_command('update-grub')

    def unpack(self) -> None:
        archive = SettingsManager.components.trycast(ArchivesSetting).selected_archive()
        Logger.log('Extracting rootfs archive "{name}"'.format(name=archive.name))
        extract_archive(archive, SettingsManager.disk.target_path)
