from astra_installer.commands import Chroot
from astra_installer.logs.logger import Logger
from astra_installer.settings.manager import SettingsManager


class LocaleInstall:
    def __init__(self) -> None:
        self.chroot = Chroot(SettingsManager.disk.target_path)

    def write_locale(self, locale: str) -> None:
        locale_text = 'LANG="{locale}"'.format(locale=locale)
        self.chroot.create_file('/etc/default/locale', locale_text)

    def write_localegen(self) -> None:
        locale_gen_text = '\n'.join(SettingsManager.system_locale.selected_locales_with_codeset_and_charset())
        self.chroot.create_file('/etc/locale.gen', locale_gen_text)

    def install(self) -> None:
        locale = SettingsManager.system_locale.selected_locales_with_codeset()[0]
        Logger.log('Setting locale to {locale}'.format(locale=locale))
        self.write_locale(locale)
        self.write_localegen()
        self.chroot.run_command('locale-gen')
        self.chroot.run_command('update-locale LANG={locale}'.format(locale=locale))
