from typing import Dict

from astra_installer.logs.logger import Logger
from astra_installer.logs.system_log_saver import SystemLogSaver
from astra_installer.settings.manager import SettingsManager
from astra_installer.settings.security_feature import SecurityFeature
from astra_installer.setup.common.disk import DiskInstall


class DiskInstallOEM(DiskInstall):
    def __init__(self) -> None:
        super().__init__()

    def save_logs_at_finish(self) -> None:
        Logger.log('Collecting system info and logs')
        SystemLogSaver.save_logs('/var/log/astra-installer/finish')

    def cleanup(self) -> None:
        Logger.log('Cleaning up installed system')
        # Skip apt-get clean if secdel is active
        features = {feature.ident: feature for feature in
                    SettingsManager.security.features}  # type: Dict[str, SecurityFeature]
        if 'astra-secdel-swapwiper' in features and not features['astra-secdel-swapwiper'].is_active():
            self.chroot.run_command('apt-get clean')

    def finalize(self) -> None:
        Logger.log('Finalizing installation')
        self.save_logs_at_finish()
        self.cleanup()
        self.update_grub()
        self.setfsilev()
