import traceback
from typing import TYPE_CHECKING

from astra_installer.logs.logger import Logger
from astra_installer.settings.manager import SettingsManager
from astra_installer.settings.progress_manager import InstallationStatus
from astra_installer.settings.progress_manager import ProgressManager
from astra_installer.setup.common.security import SecurityInstall

if TYPE_CHECKING:
    from gettext import gettext as _


class SecurityInstallOEM(SecurityInstall):
    def __init__(self) -> None:
        super().__init__()

    def setup(self, status: InstallationStatus) -> None:
        Logger.log('Applying security features')
        features = [feature for feature in SettingsManager.security.features if feature.enabled]
        for index, feature in enumerate(features):
            Logger.log('Processing security feature "{name}". '
                       'Selected: {selected}'.format(name=feature.name,
                                                     selected=feature.selected))
            if self.is_feature_dependencies_satisfied(feature):
                try:
                    self.apply_security_feature(feature)
                    status.successful_steps.append(_('additional OS settings') + ': ' + _(feature.name))
                except Exception:
                    status.failed_steps.append(_('additional OS settings') + ': ' + _(feature.name))
                    Logger.log(_('Failed to setup {name}').format(name=feature.name))
                    Logger.log(traceback.format_exc())
            else:
                Logger.log('Skipping "{name}". Dependencies are not satisfied.\n'
                           'Dependencies: {packages}'.format(name=feature.name,
                                                             packages=', '.join(feature.packages)))
            percentage = int(ProgressManager.percentage(index + 1, len(features)))
            ProgressManager.increment_by_percent_of_current_interval(percentage)
