from astra_installer.logs.logger import Logger
from astra_installer.settings.manager import SettingsManager
from astra_installer.setup.common.tasks import TasksInstall


class TasksInstallOEM(TasksInstall):
    def __init__(self) -> None:
        super().__init__()

    def update(self) -> None:
        if SettingsManager.systeminfo.has_valid_repository:
            self.chroot.apt_get_update()
        else:
            Logger.log('Skipping apt-get update. Repository is unavailable.')

    def dist_upgrade(self) -> None:
        if SettingsManager.systeminfo.has_valid_repository:
            # You need to combine it with --force-confdef to let dpkg
            # overwrite configuration files that you have not modified.
            confopts = ['-o', 'Dpkg::Options::="--force-confdef"',
                        '-o', 'Dpkg::Options::="--force-confold"']
            self.chroot.apt_get(['dist-upgrade', '--show-progress'], confopts=confopts)
        else:
            Logger.log('Skipping apt-get dist-upgrade. Repository is unavailable.')

    def install(self) -> None:
        if SettingsManager.systeminfo.has_valid_repository:
            super().install()
        else:
            Logger.log('Skipping installing packages. Repository is unavailable.')
