from astra_installer import globvars
from astra_installer.settings.archives import ArchivesSetting
from astra_installer.settings.manager import SettingsManager
from astra_installer.setup.common.setup import Setup
from astra_installer.setup.oem.setup import SetupOEM

if not globvars.oem_mode:
    from astra_installer.setup.archive.setup import SetupArchive
    from astra_installer.setup.e2k8c.setup import SetupE2K8C
    from astra_installer.setup.mips.setup import SetupMIPS


class SetupCreator:
    @staticmethod
    def create() -> Setup:
        if SettingsManager.systeminfo.arch == 'e2k-8c':
            return SetupE2K8C()
        elif SettingsManager.systeminfo.arch == 'mips':
            return SetupMIPS()
        elif isinstance(SettingsManager.components, ArchivesSetting):
            return SetupArchive()
        elif SettingsManager.systeminfo.oem:
            return SetupOEM()
        else:
            return Setup()
