from typing import Optional, Dict, TYPE_CHECKING

if TYPE_CHECKING:
    from gettext import gettext as _


class ConfigFile:
    def __init__(self,
                 text: str,
                 name: str = None,
                 filename: str = None,
                 gpt_support: bool = False,
                 description: str = None,
                 recomended: bool = False,
                 red_book: bool = False,
                 snapshots_support: bool = False,
                 is_default: bool = False) -> None:
        self.__name = name
        self.__text = text
        self.__description = description
        self.__filename = filename
        self.__gpt_support = gpt_support
        self.__recomended = recomended
        self.__is_default = is_default
        self.__red_book = red_book
        self.__snapshots_support = snapshots_support

    @staticmethod
    def from_data(data: Dict[str, str]):  # -> LayoutConfigFile
        with open(data.get('path'), 'r') as file:
            text = file.read()

        return ConfigFile(name=data.get('name', _('Untitled')),
                          description=data.get('description'),
                          filename=data.get('filename'),
                          gpt_support=data.get('gpt_support', False),
                          recomended=data.get('recomended', False),
                          red_book=data.get('red_book', False),
                          snapshots_support=data.get('snapshots_support', False),
                          is_default=data.get('is_default', False),
                          text=text)

    @property
    def name(self) -> Optional[str]:
        return self.__name

    @property
    def source_text(self) -> str:
        return self.__text

    @property
    def description(self) -> Optional[str]:
        return self.__description

    @property
    def filename(self) -> Optional[str]:
        return self.__filename

    @property
    def gpt_support(self) -> bool:
        return self.__gpt_support

    @property
    def recomended(self) -> bool:
        return self.__recomended

    @property
    def red_book(self) -> bool:
        return self.__red_book

    @property
    def snapshots_support(self) -> bool:
        return self.__snapshots_support

    @property
    def is_default(self) -> bool:
        return self.__is_default
