from typing import List, Tuple, Set

from blivet.actionlist import ActionList
from blivet.deviceaction import DeviceAction
from blivet.devices.disk import DiskDevice
from blivet.i18n import _ as blivet_translate


class DeviceActionUtils:
    @staticmethod
    def is_edit_action(action: DeviceAction) -> bool:
        return action.is_destroy or action.is_resize or action.is_remove

    @staticmethod
    def action_info(action: DeviceAction) -> str:
        text = action.type_desc
        if action.is_resize:
            text += ' ({})'.format(action.resize_string)
        if action.is_format:
            text += blivet_translate(" '%s' on") % action.format.name
        text += " '{}'".format(action.device.name)
        return text

    @staticmethod
    def short_actions_list(actions: ActionList) -> Tuple[Set[DiskDevice], List[DeviceAction]]:
        clean_out_disks = set()
        for action in actions:
            if action.is_format and action.format.type == 'disklabel':
                clean_out_disks.add(action.device)

        result_actions = []
        for action in actions:
            if DeviceActionUtils.is_edit_action(action) and not list(set(action.device.disks) & clean_out_disks):
                result_actions.append(action)

        return clean_out_disks, result_actions
