import gettext
from re import sub

from babel import Locale
from babel.dates import get_timezone, get_timezone_name

from astra_installer.utils import Utils

exclude_locale_list = [
    'en_US',
    'ru_RU',
]


# Deferred translations
# Hack to extract strings with gettext
# but not actually translate them where string is defined
# Please use 'from astra_installer.translator import deferredtr as _tr' in other modules
def deferredtr(text: str) -> str:
    return text


# To fix typechecker errors use the following code:
# from typing import TYPE_CHECKING
# if TYPE_CHECKING:
#    from gettext import gettext as _
class Translator:
    path = Utils.file_path('translations')
    locale = 'en_US'
    translation = gettext.translation('astra_installer', path, languages=[locale], fallback=True)
    translation.install()

    @classmethod
    def change_locale(cls, locale: str) -> None:
        translation = gettext.translation('astra_installer', cls.path, languages=[locale], fallback=True)
        translation.install()

    @staticmethod
    def locale_name(locale: str, in_locale: str) -> str:
        name = Locale.parse(locale).get_display_name(in_locale)
        if locale in exclude_locale_list:
            name = sub(r'\s*\(.*\)', '', name)
        # Uppercase first letter (language name)
        if len(name) > 2:
            return '{head}{tail}'.format(head=name[:1].upper(), tail=name[1:])
        else:
            return name

    @staticmethod
    def timezone_name(timezone: str, in_locale: str) -> str:
        zone = get_timezone(timezone)
        return get_timezone_name(zone, width='short', locale=in_locale)
