import curses
import curses.ascii

from npyscreen import MiniButton, Pager
from npyscreen.wgwidget import Widget, EXITED_DOWN


class AsciiCode:
    ALT_ESC = 0x9B


class WidgetOverride(Widget):
    def set_up_handlers(self) -> None:
        super(Widget, self).set_up_handlers()
        self.handlers.update({AsciiCode.ALT_ESC: self.h_exit_escape})

    def get_and_use_key_press(self):
        curses.raw()
        curses.cbreak()
        curses.meta(True)
        self.parent.curses_pad.keypad(1)
        if self.parent.keypress_timeout:
            curses.halfdelay(self.parent.keypress_timeout)
            ch = self._get_ch()
            if ch == -1:
                return self.try_while_waiting()
        else:
            self.parent.curses_pad.timeout(-1)
            ch = self._get_ch()

        self.handle_input(ch)
        if self.check_value_change:
            self.when_check_value_changed()
        if self.check_cursor_move:
            self.when_check_cursor_moved()

        self.try_adjust_widgets()


class MiniButtonOverride(MiniButton):
    def set_up_handlers(self) -> None:
        super(MiniButton, self).set_up_handlers()
        self.handlers.update({curses.ascii.SP: self.h_select_exit})


class PagerOverride(Pager):
    def h_scroll_line_down(self, input):
        self.start_display_at += 1
        if self.scroll_exit and self.start_display_at + self.height >= len(self.values) + 1:
            self.editing = False
            self.how_exited = EXITED_DOWN
