from typing import Type, List, TYPE_CHECKING

from npyscreen import Popup, Pager
from npyscreen.fmForm import _FormBase
from npyscreen.proto_fm_screen_area import ScreenArea
from npyscreen.utilNotify import _prepare_message, _wrap_message_lines

if TYPE_CHECKING:
    from gettext import gettext as _


class DialogGeometry:
    def __init__(self,
                 dialog_class: Type[ScreenArea] = None,
                 default_lines: int = None,
                 default_columns: int = None,
                 show_atx: int = None,
                 show_aty: int = None) -> None:
        self.__default_lines = default_lines
        self.__default_columns = default_columns
        self.__show_atx = show_atx
        self.__show_aty = show_aty
        if dialog_class:
            self.get_from(dialog_class)

    def get_from(self, dialog_class: Type[ScreenArea]) -> None:
        self.__default_lines = dialog_class.DEFAULT_LINES
        self.__default_columns = dialog_class.DEFAULT_COLUMNS
        self.__show_atx = dialog_class.SHOW_ATX
        self.__show_aty = dialog_class.SHOW_ATY

    def set_to(self, dialog_class: Type[ScreenArea]) -> None:
        if self.__default_lines is not None:
            dialog_class.DEFAULT_LINES = self.__default_lines
        if self.__default_columns is not None:
            dialog_class.DEFAULT_COLUMNS = self.__default_columns
        if self.__show_atx is not None:
            dialog_class.SHOW_ATX = self.__show_atx
        if self.__show_aty is not None:
            dialog_class.SHOW_ATY = self.__show_aty


class WaitDialog:
    def __init__(self, screen: _FormBase, title: str = None, message: str = None, sub_text: str = None):
        self.__screen = screen
        self.__title = title if title else _('Please wait')
        self.__message = message
        self.__sub_text = sub_text if sub_text else _('The operation may take some time')

    def show(self):
        if self.__message:
            lines = [self.__message]
        else:
            lines = []  # type: List[str]
        lines.append(self.__sub_text)
        message_lines = _prepare_message('\n'.join(lines))

        available_height, available_width = self.__screen.useable_space()
        width = available_width // 4
        message_lines = _wrap_message_lines(message_lines, width)
        height = len(message_lines) + 4

        old_geometry = DialogGeometry(Popup)
        new_geometry = DialogGeometry(default_lines=height,
                                      default_columns=width,
                                      show_atx=(available_width - width) // 2,
                                      show_aty=(available_height - height) // 2)
        new_geometry.set_to(Popup)

        form = Popup(name=self.__title, color='STANDOUT')
        form.preserve_selected_widget = True
        pager = form.add(Pager, editable=False)
        pager.values = message_lines
        form.display()

        old_geometry.set_to(Popup)
