from typing import Optional

from npyscreen import setTheme

from astra_installer.settings.autoinstall_config import AutoinstallConfigLoader
from astra_installer.settings.autoinstall_manager import AutoinstallSettingsManager
from astra_installer.settings.manager import SettingsManager
from astra_installer.tui.theme import DefaultTheme
from astra_installer.utils import Utils
from astra_installer_console.console_installer import ConsoleInstaller
from astra_installer_console.ui.installation_form import InstallationForm


class AutoInstaller(ConsoleInstaller):
    STARTING_FORM = 'installation'

    def __init__(self, locale: str, preseed: str):
        super().__init__(locale)
        self.preseed = preseed

    def onStart(self) -> None:
        Utils.override_system_signals()
        self.setup_backend()
        self.set_core_messages_level(1)
        SettingsManager.installer_locale.change_locale(self.locale)
        self.translate_global_variables()
        self.override_base_methods()
        setTheme(DefaultTheme)
        self.addForm('installation', InstallationForm)

    def setup_backend(self) -> None:
        loader = AutoinstallConfigLoader(self.preseed)
        config = loader.load()
        AutoinstallSettingsManager.create_settings(config)

    @staticmethod
    def preseed_file(cmdline_argument: str) -> Optional[str]:
        if cmdline_argument:
            return cmdline_argument
        kernel_cmdline_url = Utils.preseed_cmdline_option()
        if kernel_cmdline_url:
            if Utils.download_preseed(kernel_cmdline_url):
                return '/tmp/preseed.yaml'
        return Utils.find_preseed_path()
