from typing import Callable, Optional, TYPE_CHECKING

from npyscreen import ActionPopup, Pager

from astra_installer.settings.manager import SettingsManager
from astra_installer.settings.systeminfo import AstraEdition
from astra_installer_console.ui.checkbox_callback import CheckBoxCallback
from astra_installer_console.ui.password_text import TitlePasswordEntry

if TYPE_CHECKING:
    from gettext import gettext as _


class GrubSettingsDialog(ActionPopup):
    def __init__(self,
                 settings_changed_callback: Callable = None,
                 *args, **kwargs):
        self.nextrely = None  # type: Optional[int]
        self.editw = None  # type: Optional[int]
        self.__settings_changed_callback = settings_changed_callback  # ???
        self.__setup_grub_password_checkbox = None  # type: Optional[CheckBoxCallback]
        self.__password = None  # type: Optional[TitlePasswordEntry]
        self.__password_confirmation = None  # type: Optional[TitlePasswordEntry]
        self.__comment = None  # type: Optional[Pager]
        super().__init__(*args, **kwargs)

    def find_cancel_button(self) -> None:
        self.editw = len(self._widgets__) - 1

    def create_control_buttons(self):
        close_button_text = _('Close')
        self._add_button('ok_button',
                         self.__class__.OKBUTTON_TYPE,
                         close_button_text,
                         0 - self.__class__.OK_BUTTON_BR_OFFSET[0],
                         0 - self.__class__.OK_BUTTON_BR_OFFSET[1] - len(close_button_text),
                         None)

    def edit(self) -> None:
        self.editing = True
        super().edit()

    def create(self):
        select_widgets_at = 31
        height, width = self.useable_space()

        self.nextrely = (height - 7) // 2
        self.__setup_grub_password_checkbox = self.add(CheckBoxCallback,
                                                       name=_('Setup bootloader (GRUB) password'),
                                                       value=(SettingsManager.systeminfo.edition == AstraEdition.SE),
                                                       toggled_callback=self.__setup_grub_password_checkbox_toggled)
        self.nextrely += 1
        self.__password = self.add(TitlePasswordEntry,
                                   editable=self.__setup_grub_password_checkbox.value,
                                   begin_entry_at=select_widgets_at,
                                   name=_('Password:'),
                                   value_changed_callback=self.__password_changed,
                                   value='')

        self.__password_confirmation = self.add(TitlePasswordEntry,
                                                editable=self.__setup_grub_password_checkbox.value,
                                                begin_entry_at=select_widgets_at,
                                                name=_('Password confirmation:'),
                                                value_changed_callback=self.__password_confirmation_changed,
                                                value='')
        self.nextrely += 1
        self.__comment = self.add(Pager,
                                  values=[_(
                                      'If the password is empty, then the administrator password will be set by default.')],
                                  autowrap=True,
                                  editable=False)

    def __setup_grub_password_checkbox_toggled(self, _: bool) -> None:
        self.__password.editable = self.__setup_grub_password_checkbox.value
        self.__password_confirmation.editable = self.__setup_grub_password_checkbox.value
        self.settings_changed()

    def __password_changed(self, widget) -> None:
        self.settings_changed()

    def __password_confirmation_changed(self, widget) -> None:
        self.settings_changed()

    def settings_changed(self):
        if callable(self.__settings_changed_callback):
            # print(self.__setup_grub_password_checkbox.value)
            self.__settings_changed_callback(setup_grub_password=self.__setup_grub_password_checkbox.value,
                                             grub_password=self.__password.value,
                                             grub_password_confirmation=self.__password_confirmation.value)
