from typing import TYPE_CHECKING

from npyscreen import TitleText

from astra_installer.settings.manager import SettingsManager
from astra_installer.settings.systeminfo import AstraEdition
from astra_installer_console.ui.grub_button import GrubButton

if TYPE_CHECKING:
    from gettext import gettext as _


class GrubTitle(TitleText):
    _entry_type = GrubButton

    def __init__(self, *args, **kwargs):
        super().__init__(settings_changed_callback=self.__settings_changed,
                         *args, **kwargs)
        self.__setup_grub_password = False  # type: bool
        self.__grub_password = ''  # type : str
        self.__grub_password_confirmation = ''  # type : str
        self.__setup()

    @property
    def setup_grub_password(self) -> bool:
        return self.__setup_grub_password

    @property
    def grub_password(self) -> str:
        return self.__grub_password

    @property
    def grub_password_confirmation(self) -> str:
        return self.__grub_password_confirmation

    def __setup(self) -> None:
        self.__setup_grub_password = (SettingsManager.systeminfo.edition == AstraEdition.SE)
        self.__update_info_label()

    def __settings_changed(self,
                           setup_grub_password: bool = False,
                           grub_password: str = '',
                           grub_password_confirmation: str = '') -> None:
        self.__setup_grub_password = setup_grub_password
        self.__grub_password = grub_password
        self.__grub_password_confirmation = grub_password_confirmation
        self.__update_info_label()

    def __update_info_label(self) -> None:
        if not self.__setup_grub_password:
            text = _('Password not setuped')
        else:
            if self.__grub_password:
                text = _('Password setuped')
            else:
                text = _('Setup the administrator password')
        self.value = text
