from typing import Tuple, TYPE_CHECKING

from npyscreen import TitleText

from astra_installer.settings.manager import SettingsManager

if TYPE_CHECKING:
    from gettext import gettext as _


class HostnameManager:
    def __init__(self, form, select_widgets_at, max_width):
        self.form = form
        self.backend = SettingsManager.hostname
        self.hostname = None  # type: TitleText
        self.setup(select_widgets_at, max_width)

    def setup(self, select_widgets_at, max_width) -> None:
        self.hostname = self.form.add(TitleText,
                                      name=_('Hostname:'),
                                      begin_entry_at=select_widgets_at,
                                      max_width=max_width,
                                      value=self.backend.hostname)

    def validate(self) -> Tuple[bool, str]:
        valid, error = self.backend.is_valid_hostname(self.hostname.value)
        if valid:
            self.backend.hostname = self.hostname.value
            return True, ''
        else:
            return False, _(error)
