from typing import Optional, List, TYPE_CHECKING

from astra_installer.settings.component import Component
from astra_installer.settings.manager import SettingsManager
from astra_installer_console.ui.title_combobox_pair import TitleComboBoxPair

if TYPE_CHECKING:
    from gettext import gettext as _

class KernelManager:
    def __init__(self, form, select_widgets_at, max_width):
        self.form = form
        self.kernel_combobox = None  # type: Optional[TitleComboBoxPair]
        self.setup(select_widgets_at, max_width)

    def setup(self, select_widgets_at, max_width) -> None:
        values = []
        current_index = 0
        for index, package in enumerate(SettingsManager.kernel.available_packages):
            values.append((package, package))
            if package == SettingsManager.kernel.package:
                current_index = index

        self.layout_combobox = self.form.add(TitleComboBoxPair,
                                             name=_('The kernel to install:'),
                                             begin_entry_at=select_widgets_at,
                                             max_width=max_width,
                                             value=current_index,
                                             values=values,
                                             selection_changed_callback=self.kernel_changed)

        self.kernel_changed(SettingsManager.kernel.package)

    def kernel_changed(self, value: str) -> None:
        SettingsManager.kernel.package = value
