from re import match
from typing import Optional, TYPE_CHECKING

from astra_installer.commands import run_command
from astra_installer.settings.manager import SettingsManager
from astra_installer.tui.wait_dialog import WaitDialog
from astra_installer.tui.wait_launcher import WaitLauncher
from astra_installer.utils import Utils
from astra_installer_console.ui.title_combobox_pair import TitleComboBoxPair

if TYPE_CHECKING:
    from gettext import gettext as _


class LayoutManager:
    def __init__(self, form, select_widgets_at, max_width):
        self.form = form
        self.layout_combobox = None  # type: Optional[TitleComboBoxPair]
        self.wait_dialog_enabled = False  # TODO: del
        self.setup(select_widgets_at, max_width)

    def setup(self, select_widgets_at, max_width) -> None:
        values = []
        current_index = 0
        for index, pair in enumerate(SettingsManager.layout.keys.items()):
            layout_key, text = pair
            values.append((_(text), layout_key))
            if layout_key == SettingsManager.layout.default_key:
                current_index = index

        self.layout_combobox = self.form.add(TitleComboBoxPair,
                                             name=_('Language switching:'),
                                             begin_entry_at=select_widgets_at,
                                             max_width=max_width,
                                             value=current_index,
                                             values=values,
                                             selection_changed_callback=self.layout_changed)

        self.layout_changed(SettingsManager.layout.default_key)
        self.wait_dialog_enabled = True

    def layout_changed(self, value: str) -> None:
        launcher = WaitLauncher(time=1.0, main_task=self.change_layout, wait_task=self.show_wait_dialog)
        launcher.set_main_args(value)
        launcher.run()

    def show_wait_dialog(self) -> None:
        if self.wait_dialog_enabled:
            WaitDialog(screen=self.form, message=_('Applying layout...')).show()

    def change_layout(self, value: str) -> None:
        SettingsManager.layout.selected_keys = [value]
        if Utils.is_console_session():
            self.change_keyboard_keys(value)
        else:
            SettingsManager.layout.apply()

    def change_keyboard_keys(self, key: str) -> None:
        lines = []
        for line in open(SettingsManager.layout.keyboard_file, 'r').read().splitlines():
            if match(r'XKBOPTIONS\s*=\s*".+"', line):
                lines.append('XKBOPTIONS="{key},grp_led:scroll"'.format(key=key))
            else:
                lines.append(line)
        open(SettingsManager.layout.keyboard_file, 'w').write('\n'.join(lines))

        run_command('setupcon --save')
