from typing import Callable, Optional, TYPE_CHECKING

from npyscreen.utilNotify import notify_confirm

from astra_installer_console.ui.password_text import TitlePasswordEntry
from astra_installer_console.ui.question_dialog import QuestionDialog

if TYPE_CHECKING:
    from gettext import gettext as _


class PassphraseDialog(QuestionDialog):
    def __init__(self,
                 title: str,
                 confirmed_callback: Callable = None,
                 *args, **kwargs):
        self.__password_entry = None  # type: Optional[TitlePasswordEntry]
        self.__password_confirmation_entry = None  # type: Optional[TitlePasswordEntry]
        super().__init__(title=title, text='', confirmed_callback=confirmed_callback, *args, **kwargs)

    @property
    def passphrase(self) -> str:
        return self.__password_entry.value

    @property
    def password_confirmation(self) -> str:
        return self.__password_confirmation_entry.value

    def create(self) -> None:
        select_widgets_at = 25

        self.__password_entry = self.add(TitlePasswordEntry,
                                         begin_entry_at=select_widgets_at,
                                         name=_('Password:'))
        self.__password_confirmation_entry = self.add(TitlePasswordEntry,
                                                      begin_entry_at=select_widgets_at,
                                                      name=_('Password confirmation:'))

    def dialog_confirmed(self) -> None:
        if not self.passphrase:
            notify_confirm(_('Passphrase is empty'),
                           title=_('Error'),
                           editable=False)
            return

        if len(self.passphrase) < 8:
            notify_confirm(_('The passphrase is too short'),
                           title=_('Error'),
                           editable=False)
            return

        if not self.password_confirmation:
            notify_confirm(_('Confirm passphrase'),
                           title=_('Error'),
                           editable=False)
            return

        if self.passphrase != self.password_confirmation:
            notify_confirm(_('Passphrases do not match'),
                           title=_('Error'),
                           editable=False)
            return

        super().dialog_confirmed()
