from typing import Callable, TYPE_CHECKING

from npyscreen import ButtonPress, Pager
from npyscreen.utilNotify import ConfirmCancelPopup

if TYPE_CHECKING:
    from gettext import gettext as _


class QuestionDialog(ConfirmCancelPopup):
    def __init__(self,
                 title: str,
                 text: str,
                 ok_button_text: str = None,
                 cancel_button_text: str = None,
                 confirmed_callback: Callable = None,
                 *args, **kwargs):
        self.confirmed_callback = confirmed_callback
        self.text = text
        self.ok_button_text = ok_button_text
        self.cancel_button_text = cancel_button_text
        self.confirmed = False
        super().__init__(name=title, color='STANDOUT', *args, **kwargs)

    def create_control_buttons(self) -> None:
        height, width = self.useable_space()

        ok_button_text = self.ok_button_text if self.ok_button_text else _('Ok')
        install_button_x = width - len(ok_button_text) - 4
        self.add(ButtonPress,
                 name=ok_button_text,
                 when_pressed_function=self.dialog_confirmed,
                 rely=-2,
                 relx=install_button_x,
                 use_max_space=True)

        cancel_button_text = self.cancel_button_text if self.cancel_button_text else _('Cancel')
        self.add(ButtonPress,
                 name=cancel_button_text,
                 when_pressed_function=self.cancel_pressed,
                 rely=-2,
                 relx=install_button_x - len(cancel_button_text) - 3,
                 use_max_space=True)

        self.editw = len(self._widgets__) - 2

    def dialog_confirmed(self) -> None:
        self.confirmed = True
        self.editing = False
        if callable(self.confirmed_callback):
            self.confirmed_callback()

    def cancel_pressed(self) -> None:
        self.confirmed = False
        self.editing = False

    def create(self) -> None:
        self.preserve_selected_widget = True

        self.add(Pager,
                 values=self.text.split('\n'),
                 autowrap=True,
                 scroll_exit=True)
