from typing import Callable, Tuple

from npyscreen import CheckBox, SelectOne


class RadioButton(CheckBox):
    False_box = '( )'
    True_box = '(*)'

    def __init__(self, screen, toggled_callback: Callable = None, *args, **kwargs):
        self.toggled_callback = toggled_callback
        self.__show_box = True
        super().__init__(screen, *args, **kwargs)

    def h_toggle(self, ch: str) -> None:
        self.value = True
        self.whenToggled()

    def whenToggled(self) -> None:
        if callable(self.toggled_callback):
            self.toggled_callback()

    def update(self, clear=True):
        if clear: self.clear()
        if self.hidden:
            self.clear()
            return False
        if self.hide: return True

        if self.__show_box:
            if self.value:
                cb_display = self.__class__.True_box
            else:
                cb_display = self.__class__.False_box
        else:
            cb_display = ''

        if self.do_colors():
            self.parent.curses_pad.addstr(self.rely, self.relx, cb_display, self.parent.theme_manager.findPair(self, self.controlColor))
        else:
            self.parent.curses_pad.addstr(self.rely, self.relx, cb_display)

        self._update_label_area()

    def set_box_visible(self, visible):
        self.__show_box = visible

class RadioButtonsList(SelectOne):
    _contained_widgets = RadioButton

    def __init__(self, screen, values_changed_callback: Callable = None, *args, **kwargs):
        self.values_changed_callback = values_changed_callback
        self._old_value = kwargs.get('value', None)
        super().__init__(screen, *args, **kwargs)

    def when_value_edited(self) -> None:
        if callable(self.values_changed_callback):
            self.values_changed_callback()

    def set_selected_index(self, index: int) -> None:
        if index >= 0:
            self.value = [index]
        else:
            self.value = []
        self._old_value = self.value

    def set_current_index(self, index: int) -> None:
        old_value = self._old_value
        self.set_selected_index(index)
        if not old_value == self._old_value and callable(self.values_changed_callback):
            self.values_changed_callback()

    def set_boxes_visible(self, visible):
        for widget in self._my_widgets:
            widget.set_box_visible(visible)

class RadioButtonsDataList(RadioButtonsList):
    def display_value(self, value: Tuple):
        text, value = value
        return text

    def get_selected_values(self):
        try:
            return [self.values[index] for index in self.value]
        except IndexError:
            return None

    def get_selected_value(self):
        try:
            return next(iter(self.get_selected_values()), None)
        except TypeError:
            return None, None
