from typing import TYPE_CHECKING

from npyscreen import MultiLineEdit
from npyscreen.wgwidget import EXITED_ESCAPE

from astra_installer_console.ui.base_main_form import BaseMainForm

if TYPE_CHECKING:
    from gettext import gettext as _


class TextEditorForm(BaseMainForm):
    def __init__(self, text: str = None, *args, **kwargs):
        self.text_edit_widget = None  # type: MultiLineEdit
        self.text = text
        super().__init__(*args, **kwargs)

    def set_up_exit_condition_handlers(self) -> None:
        super().set_up_exit_condition_handlers()
        self.how_exited_handers.update({EXITED_ESCAPE: self.exit_escape})

    def exit_escape(self) -> None:
        self.editw = len(self._widgets__) - 2

    def create_widgets(self) -> None:
        self.text_edit_widget = self.add(MultiLineEdit,
                                         value=self.text,
                                         max_height=self.back_button.rely - 3)

        self.set_control_button_name(self.back_button, _('Cancel'))
        self.set_control_button_name(self.next_button, _('Apply'))
        self.next_button.when_pressed_function = self.ok_pressed

    def set_text(self, text: str) -> None:
        self.text_edit_widget.value = text

    def get_text(self) -> str:
        return self.text_edit_widget.value

    def ok_pressed(self) -> None:
        self.text_changed(self.get_text())
        self.switch_previous_form()

    def text_changed(self, text: str) -> None:
        pass
