from npyscreen import NPSAppManaged, setTheme
from npyscreen.wgwidget import Widget

from astra_installer.tui.overrides_fixes_methods import WidgetOverride
from astra_installer.tui.theme import DefaultTheme
from astra_installer.utils import Utils
from astra_installer_launcher.ui.main_form import MainForm
from astra_installer_launcher.utils import clear_console


class Launcher(NPSAppManaged):
    def __init__(self):
        self.last_command = None  # type: Optional[Callable]
        super().__init__()

    def __execute_autoinstaller(self) -> None:
        form = self.getForm('MAIN')
        if form.autoinstaller_item:
            self._THISFORM = form
            form.h_line_toggled(form.autoinstaller_item)

    def __set_locale(self) -> None:
        try:
            locale_option = Utils.locale_cmdline_option()
        except:
            return

        main_form = self.getForm('MAIN')  # type: MainForm
        if locale_option == 'ru':
            main_form.set_locale('ru_RU')
        elif locale_option == 'en':
            main_form.set_locale('en_US')
        else:
            main_form.set_locale('ru_RU')

    def onStart(self) -> None:
        Utils.override_system_signals()
        setTheme(DefaultTheme)
        self.override_base_methods()
        self.addForm('MAIN', MainForm)
        self.__set_locale()
        self.__execute_autoinstaller()

    def exit(self, last_command=None) -> None:
        self.last_command = last_command
        self.setNextForm(None)
        self.switchFormNow()

    def on_exit(self) -> None:  # TODO: make override onCleanExit
        clear_console()
        if callable(self.last_command):
            self.last_command()

    @staticmethod
    def override_base_methods():
        Widget.set_up_handlers = WidgetOverride.set_up_handlers
        Widget.get_and_use_key_press = WidgetOverride.get_and_use_key_press
