import curses
from typing import Tuple

from npyscreen import FormBaseNew


class FormWithFooter(FormBaseNew):
    def __init__(self, footer=None, *args, **keywords):
        self.footer = footer
        super().__init__(*args, **keywords)

    def draw_form(self) -> None:
        super().draw_form()
        if self.footer is not None:
            self.draw_footer()

    def display_footer_advert_at(self) -> Tuple[int, int]:
        return self.lines - 1, 2

    def draw_footer(self) -> None:
        footer_text = self.footer
        if isinstance(footer_text, bytes):
            footer_text = footer_text.decode('utf-8', 'replace')
        y, x = self.display_footer_advert_at()
        self.add_line(y, x,
                      footer_text,
                      self.make_attributes_list(footer_text, curses.A_NORMAL),
                      self.columns - x - 1)
