from typing import TYPE_CHECKING

from npyscreen import MultiLine

from astra_installer_launcher.ui.translatable_text import TranslatableText

if TYPE_CHECKING:
    from gettext import gettext as _


class HotkeysWidget(MultiLine):
    _contained_widgets = TranslatableText

    def __init__(self, screen, values=[], *args, **kwargs):
        self.__timeout_text = ""
        self.values = values
        super().__init__(screen, values=values, editable=False, *args, **kwargs)
        self.setup()

    def setup(self) -> None:
        self.retranslate()

    def retranslate(self, text: str = None) -> None:
        self.values.clear()

        en_text = 'Change language'
        locale_text = _('Change language')
        text = '{hotkey} - {text}'.format(hotkey='F2',
                                          text=locale_text)
        if en_text != locale_text:
            text += ' ({text})'.format(text=en_text)

        if self.__timeout_text:
            self.values.append(self.__timeout_text)

        self.values.append(text)

        self.values.append('{hotkey} - {text}'.format(hotkey='F10',
                                                      text=_('Shutdown')))

        self.values.append('↓ - {down} | ↑ - {up} | ENTER, SPACE - {run}'.format(down=_('Down'),
                                                                                 up=_('Up'),
                                                                                 run=_('Execute')))

    def calculate_area_needed(self):
        return len(self.values), len(max(self.values, key=lambda value: len(value))) + 1 if len(self.values) > 0 else 0

    def set_timeout(self, text):
        self.__timeout_text = text
