import curses
from typing import TYPE_CHECKING

from astra_installer.translator import Translator
from astra_installer_launcher.ui.select_form import SelectForm

if TYPE_CHECKING:
    from gettext import gettext as _


class SelectLanguage(SelectForm):
    def __init__(self, locales, current_locale, *args, **keywords):
        items = []
        for locale in locales:
            text = Translator.locale_name(locale, current_locale)
            if locale != current_locale:
                text += ' - ' + Translator.locale_name(locale, locale)
            items.append((text, locale))

        title = _('Select language')
        footer = 'F2, ESC - {cancel_text} | ENTER, SPACE - {apply_text}'.format(cancel_text=_('Cancel'),
                                                                                apply_text=_('Apply'))
        max_len = max(len(title), len(footer))
        for item in items:
            max_len = max(len(item[0]), max_len)

        columns = max_len + 6

        super().__init__(name=title, footer=footer, columns=columns, items=items, *args, **keywords)

    def create(self):
        super().create()
        self.add_handlers({curses.KEY_F2: self.h_cancel})

    def locale(self):
        return self.value[1] if self.value is not None else None
