from curses import endwin
from os import system
from re import match
from typing import Dict, Optional, TYPE_CHECKING

from astra_installer.settings.manager import SettingsManager
from astra_installer_launcher.config import main_menu_list, keypress_waiting_time

if TYPE_CHECKING:
    from gettext import gettext as _


def clear_console() -> None:
    endwin()  # TODO Probably causes a memory leak
    system('clear')


class Config:
    @staticmethod
    def get_main_menu_data():
        return main_menu_list

    @staticmethod
    def get_main_menu_texts():
        items = Config.parse_main_menu_data()
        items_text = []
        for item in items:
            items_text.append(Config.menu_data_text(item))

        return items_text

    @staticmethod
    def menu_data_text(item: Dict) -> Optional[str]:
        text = None
        texts = item.get('texts', None)
        if texts:
            text = texts.get(SettingsManager.installer_locale.selected, None)
            if not text:
                text = texts.get('no_locale', None)
                text = _(text)
        return text

    @staticmethod
    def parse_main_menu_data():
        all_data = []
        text_pattern = r'^(?P<marker>text[_]?)(?P<locale>.*)$'

        for item in main_menu_list:
            texts = {}
            item_data = {}

            for key in item.keys():
                result = match(text_pattern, key)
                if result is not None and result.group('marker'):
                    locale = result.group('locale')
                    if locale:
                        texts[locale] = item[key]
                    else:
                        texts['no_locale'] = item[key]
                else:
                    item_data[key] = item[key]
            item_data['texts'] = texts
            all_data.append(item_data)

        return all_data

    @staticmethod
    def get_keypress_waiting_time():
        return keypress_waiting_time
